#
# spec file for package python-django-rest-framework-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python39 1
%{?sle15_python_module_pythons}
Name:           python-django-rest-framework-client
Version:        0.10.0
Release:        2.3
Summary:        Python client for a Django REST Framework based web site
License:        MIT
URL:            https://github.com/dkarchmer/django-rest-framework-client
Source:         https://github.com/dkarchmer/django-rest-framework-client/archive/v%{version}.tar.gz#/django-rest-framework-client-%{version}.tar.gz
Patch0:         python-django-rest-framework-client-no-mock.patch
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
# /SECTION
BuildRequires:  fdupes
Requires:       python-Django
Requires:       python-requests
BuildArch:      noarch
%python_subpackages

%description
Python client for a Django REST Framework based web site.

%prep
%autosetup -p1 -n django-rest-framework-client-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/drf_client
%{python_sitelib}/django_rest_framework_client-%{version}.dist-info

%changelog
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Feb 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.10.0:
  * Add support to use a permanent Token.
  * Fix bug using BaseFacade
  * Fix bug using old Facade instead of BaseFacade
  * Add isort and Black as formatter
  * Add static BaseFacade class to allow access to API class and BaseMain
    options
  * Remove support for Python 3.8.
  * Add set of `raw_*` methods that do not process results.
  * Migrated to Python 3.10, Python 2 is not supported anymore
  * Resource class methods respect additional `**kwargs` and `extra_headers`
    parameters and pass them on to the underlying `requests` methods
  * Fix to support `http://` schema in the server url
  * Add USE_DASHES option to automatically replace underscores ("_") with
    dashes ("-")
  * Allow `delete()` method to accept optional `payload`
  * Fix BaseMain Login method
  * Add base_main helper
  * Add method to be able to support resource names with "-" in the name
  * Support Login based on usernames or email keys
  * Drop support for Python 2. Test on v3.8 and v3.9
  * Remove dependency on unitest2
- Switch to autosetup and pyproject macros.
- Drop patch python-django-rest-framework-client-no-unittest2.patch, no longer
  required.
- Refresh python-django-rest-framework-client-no-mock.patch
* Thu May 12 2022 pgajdos@suse.com
- to not require python-mock for build
- added patches
  fix https://github.com/dkarchmer/django-rest-framework-client/issues/7
  + python-django-rest-framework-client-no-mock.patch
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Mon Jun  1 2020 pgajdos@suse.com
- use %%pytest macro
- added patches
  unittest2 is not neccessary for python3
  + python-django-rest-framework-client-no-unittest2.patch
* Thu Apr 11 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.1.1
